/*
 * This Source Code Form is subject to the terms of the Mozilla Public License,
 * v. 2.0. If a copy of the MPL was not distributed with this file, You can
 * obtain one at https://mozilla.org/MPL/2.0/.
 *
 * Copyright 2025 Nicola Clark
 */

use std::env;

use log::LevelFilter;

fn main() {
  colog::init();
  if let Ok(b_log_level) = env::var("B_LOG_LEVEL") {
    log::set_max_level(match b_log_level.as_str() {
      "off" => LevelFilter::Off,
      "error" => LevelFilter::Error,
      "warn" => LevelFilter::Warn,
      "debug" => LevelFilter::Debug,
      "trace" => LevelFilter::Trace,
      _ => LevelFilter::Info,
    });
  } else {
    log::set_max_level(LevelFilter::Info);
  }

  log::info!("spoon-blog v{}", env!("CARGO_PKG_VERSION"));
}
